@@ -1,6 +1,6 @@
 var a00038 =
 [
-    [ "salhelper::SingletonRef< SingletonClass >", "a00590.html", "a00590" ],
+    [ "salhelper::SingletonRef&lt; SingletonClass &gt;", "a00590.html", "a00590" ],
     [ "salhelper::m_nRef", "a00531.html#a29adac419c6a32c4b8f81339ce60c9c4", null ],
     [ "salhelper::m_pInstance", "a00531.html#abdaa045b406bfd3d1e061179e0a55710", null ]
 ];
\ No newline at end of file
